package sgc.portal.cd.cd0201.persistence;

import org.apache.ibatis.annotations.Mapper;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cd.cd0201.dto.CD02010001PSearch;
import sgc.portal.cd.cd0201.model.CD02010001P;

import java.util.List;

@Mapper
public interface CD02010001PMapper {
	
	//CON_DAY_WRK 현장일보
	List<EasyHashMap<String, Object>> getListConDayWrkCopy(CD02010001PSearch search);
	
	int deleteConDayWrk(CD02010001P cD02010001P);
	
	int deleteConDayWrkCn(CD02010001P cD02010001P);
	
	int deleteConDayWrkMan(CD02010001P cD02010001P);
	
	int deleteConDayWrkEq(CD02010001P cD02010001P);
	
	int deleteConDayWrkEqprt(CD02010001P cD02010001P);

	int deleteConDayWrkBd(CD02010001P cD02010001P);
	
	int deleteConDayWrkBdprt(CD02010001P cD02010001P);

	int deleteConDayWrkPr(CD02010001P cD02010001P);
	
    int insertConDayWrk(CD02010001P cD02010001P);
	
	int insertConDayWrkCn(CD02010001P cD02010001P);
	
	int insertConDayWrkMan(CD02010001P cD02010001P);
	
	int insertConDayWrkEq(CD02010001P cD02010001P);
	
	int insertConDayWrkEqprt(CD02010001P cD02010001P);

	int insertConDayWrkBd(CD02010001P cD02010001P);
	
	int insertConDayWrkBdprt(CD02010001P cD02010001P);

	int insertConDayWrkPr(CD02010001P cD02010001P);
    
}
